"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.containers.v1.container_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetContainerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to return.

    To get a container ID make a [ContainerService.List] request.
    """
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id"]) -> None: ...

global___GetContainerRequest = GetContainerRequest

@typing.final
class ListContainersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list containers in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListContainersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListContainersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters containers listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Container.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name="my-container"`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListContainersRequest = ListContainersRequest

@typing.final
class ListContainersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListContainersRequest.page_size], use `nextPageToken` as the value
    for the [ListContainersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.containers.v1.container_pb2.Container]:
        """List of containers in the specified folder."""

    def __init__(
        self,
        *,
        containers: collections.abc.Iterable[yandex.cloud.serverless.containers.v1.container_pb2.Container] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["containers", b"containers", "next_page_token", b"next_page_token"]) -> None: ...

global___ListContainersResponse = ListContainersResponse

@typing.final
class CreateContainerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a container in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the container.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the container."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateContainerRequest = CreateContainerRequest

@typing.final
class CreateContainerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container that is being created."""
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id"]) -> None: ...

global___CreateContainerMetadata = CreateContainerMetadata

@typing.final
class UpdateContainerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to update.

    To get a container ID make a [ContainerService.List] request.
    """
    name: builtins.str
    """New name for the container.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description for the container."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the container should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Container labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label, request the current set of labels with a [ContainerService.Get] request.
        """

    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateContainerRequest = UpdateContainerRequest

@typing.final
class UpdateContainerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container that is being updated."""
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id"]) -> None: ...

global___UpdateContainerMetadata = UpdateContainerMetadata

@typing.final
class DeleteContainerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to delete.
    To get a container ID make a [ContainerService.List] request.
    """
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id"]) -> None: ...

global___DeleteContainerRequest = DeleteContainerRequest

@typing.final
class DeleteContainerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container that is being deleted."""
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id"]) -> None: ...

global___DeleteContainerMetadata = DeleteContainerMetadata

@typing.final
class GetContainerRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REVISION_ID_FIELD_NUMBER: builtins.int
    container_revision_id: builtins.str
    """ID of the revision to return.

    To get a revision ID make a [ContainerService.ListRevisions] request.
    """
    def __init__(
        self,
        *,
        container_revision_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_revision_id", b"container_revision_id"]) -> None: ...

global___GetContainerRevisionRequest = GetContainerRevisionRequest

@typing.final
class ListContainersRevisionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    CONTAINER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list container revisions for.
    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    container_id: builtins.str
    """ID of the container to list revisions for.
    To get a container ID use a [ContainerService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available results
    is larger than `pageSize`, the service returns a [ListContainersRevisionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListContainersRevisionsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Revision.status] and [Revision.runtime] fields.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `status="ACTIVE"`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        container_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container_id", b"container_id", "folder_id", b"folder_id", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "filter", b"filter", "folder_id", b"folder_id", "id", b"id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["folder_id", "container_id"] | None: ...

global___ListContainersRevisionsRequest = ListContainersRevisionsRequest

@typing.final
class ListContainersRevisionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REVISIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListContainersRevisionsRequest.page_size], use `nextPageToken` as the value
    for the [ListContainersRevisionsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def revisions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.containers.v1.container_pb2.Revision]:
        """List of revisions for the specified folder or container."""

    def __init__(
        self,
        *,
        revisions: collections.abc.Iterable[yandex.cloud.serverless.containers.v1.container_pb2.Revision] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "revisions", b"revisions"]) -> None: ...

global___ListContainersRevisionsResponse = ListContainersRevisionsResponse

@typing.final
class DeployContainerRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    IMAGE_SPEC_FIELD_NUMBER: builtins.int
    CONCURRENCY_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    PROVISION_POLICY_FIELD_NUMBER: builtins.int
    SCALING_POLICY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    STORAGE_MOUNTS_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to create a revision for.

    To get a container ID, make a [ContainerService.List] request.
    """
    description: builtins.str
    """Description of the revision."""
    service_account_id: builtins.str
    """ID of the service account to associate with the revision."""
    concurrency: builtins.int
    """The number of concurrent requests allowed per container instance.

    The default value is 1.
    """
    @property
    def resources(self) -> yandex.cloud.serverless.containers.v1.container_pb2.Resources:
        """Resources allocated to the revision."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for the execution of the revision.

        If the timeout is exceeded, Serverless Containers responds with a 504 HTTP code.
        """

    @property
    def image_spec(self) -> global___ImageSpec:
        """Image configuration for the revision."""

    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.containers.v1.container_pb2.Secret]:
        """Yandex Lockbox secrets to be used by the revision."""

    @property
    def connectivity(self) -> yandex.cloud.serverless.containers.v1.container_pb2.Connectivity:
        """Network access. If specified the revision will be attached to specified network/subnet(s)."""

    @property
    def provision_policy(self) -> yandex.cloud.serverless.containers.v1.container_pb2.ProvisionPolicy:
        """Policy for provisioning instances of the revision.

        The policy is only applied when the revision is ACTIVE.
        """

    @property
    def scaling_policy(self) -> yandex.cloud.serverless.containers.v1.container_pb2.ScalingPolicy:
        """Policy for scaling instances of the revision."""

    @property
    def log_options(self) -> yandex.cloud.serverless.containers.v1.container_pb2.LogOptions:
        """Options for logging from the container."""

    @property
    def storage_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.containers.v1.container_pb2.StorageMount]:
        """S3 mounts to be used by the version."""

    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        description: builtins.str = ...,
        resources: yandex.cloud.serverless.containers.v1.container_pb2.Resources | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        service_account_id: builtins.str = ...,
        image_spec: global___ImageSpec | None = ...,
        concurrency: builtins.int = ...,
        secrets: collections.abc.Iterable[yandex.cloud.serverless.containers.v1.container_pb2.Secret] | None = ...,
        connectivity: yandex.cloud.serverless.containers.v1.container_pb2.Connectivity | None = ...,
        provision_policy: yandex.cloud.serverless.containers.v1.container_pb2.ProvisionPolicy | None = ...,
        scaling_policy: yandex.cloud.serverless.containers.v1.container_pb2.ScalingPolicy | None = ...,
        log_options: yandex.cloud.serverless.containers.v1.container_pb2.LogOptions | None = ...,
        storage_mounts: collections.abc.Iterable[yandex.cloud.serverless.containers.v1.container_pb2.StorageMount] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connectivity", b"connectivity", "execution_timeout", b"execution_timeout", "image_spec", b"image_spec", "log_options", b"log_options", "provision_policy", b"provision_policy", "resources", b"resources", "scaling_policy", b"scaling_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["concurrency", b"concurrency", "connectivity", b"connectivity", "container_id", b"container_id", "description", b"description", "execution_timeout", b"execution_timeout", "image_spec", b"image_spec", "log_options", b"log_options", "provision_policy", b"provision_policy", "resources", b"resources", "scaling_policy", b"scaling_policy", "secrets", b"secrets", "service_account_id", b"service_account_id", "storage_mounts", b"storage_mounts"]) -> None: ...

global___DeployContainerRevisionRequest = DeployContainerRevisionRequest

@typing.final
class ImageSpec(google.protobuf.message.Message):
    """Revision image specification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_URL_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    WORKING_DIR_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """Image URL, that is used by the revision."""
    working_dir: builtins.str
    """Override for the image's WORKDIR."""
    @property
    def command(self) -> yandex.cloud.serverless.containers.v1.container_pb2.Command:
        """Override for the image's ENTRYPOINT."""

    @property
    def args(self) -> yandex.cloud.serverless.containers.v1.container_pb2.Args:
        """Override for the image's CMD."""

    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional environment for the container."""

    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        command: yandex.cloud.serverless.containers.v1.container_pb2.Command | None = ...,
        args: yandex.cloud.serverless.containers.v1.container_pb2.Args | None = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        working_dir: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "command", b"command"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "command", b"command", "environment", b"environment", "image_url", b"image_url", "working_dir", b"working_dir"]) -> None: ...

global___ImageSpec = ImageSpec

@typing.final
class DeployContainerRevisionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REVISION_ID_FIELD_NUMBER: builtins.int
    container_revision_id: builtins.str
    """ID of the revision that is being created."""
    def __init__(
        self,
        *,
        container_revision_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_revision_id", b"container_revision_id"]) -> None: ...

global___DeployContainerRevisionMetadata = DeployContainerRevisionMetadata

@typing.final
class RollbackContainerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    REVISION_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to rollback to an old revision.

    To get a container ID, make a [ContainerService.List] request.
    """
    revision_id: builtins.str
    """ID of the revision to rollback to.

    To get a revision ID make a [ContainerService.ListRevisions] request.
    """
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        revision_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "revision_id", b"revision_id"]) -> None: ...

global___RollbackContainerRequest = RollbackContainerRequest

@typing.final
class RollbackContainerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    REVISION_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container that is being rolled back."""
    revision_id: builtins.str
    """ID of the revision that the container is being rolled back to."""
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        revision_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "revision_id", b"revision_id"]) -> None: ...

global___RollbackContainerMetadata = RollbackContainerMetadata

@typing.final
class ListContainerOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListContainerOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListContainerOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.done], [operation.Operation.created_by] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListContainerOperationsRequest = ListContainerOperationsRequest

@typing.final
class ListContainerOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListContainerOperationsRequest.page_size], use `nextPageToken` as the value
    for the [ListContainerOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified container."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListContainerOperationsResponse = ListContainerOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.clickhouse.v1.database_pb2
import yandex.cloud.mdb.clickhouse.v1.database_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DatabaseServiceStub:
    """A set of methods for managing ClickHouse Database resources.
    NOTE: these methods are available only if database management through SQL is disabled.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.GetDatabaseRequest,
        yandex.cloud.mdb.clickhouse.v1.database_pb2.Database,
    ]
    """Returns the specified ClickHouse Database resource.

    To get the list of available ClickHouse Database resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesRequest,
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesResponse,
    ]
    """Retrieves the list of ClickHouse Database resources in the specified cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.CreateDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new ClickHouse database in the specified cluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.DeleteDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified ClickHouse database."""

class DatabaseServiceAsyncStub:
    """A set of methods for managing ClickHouse Database resources.
    NOTE: these methods are available only if database management through SQL is disabled.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.GetDatabaseRequest,
        yandex.cloud.mdb.clickhouse.v1.database_pb2.Database,
    ]
    """Returns the specified ClickHouse Database resource.

    To get the list of available ClickHouse Database resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesRequest,
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesResponse,
    ]
    """Retrieves the list of ClickHouse Database resources in the specified cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.CreateDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new ClickHouse database in the specified cluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.database_service_pb2.DeleteDatabaseRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified ClickHouse database."""

class DatabaseServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing ClickHouse Database resources.
    NOTE: these methods are available only if database management through SQL is disabled.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.database_service_pb2.GetDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.database_pb2.Database, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.database_pb2.Database]]:
        """Returns the specified ClickHouse Database resource.

        To get the list of available ClickHouse Database resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesResponse, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.database_service_pb2.ListDatabasesResponse]]:
        """Retrieves the list of ClickHouse Database resources in the specified cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.database_service_pb2.CreateDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new ClickHouse database in the specified cluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.database_service_pb2.DeleteDatabaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified ClickHouse database."""

def add_DatabaseServiceServicer_to_server(servicer: DatabaseServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/clickhouse/v1/user.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xe4\x01\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuota\")\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03\"\xa1\x02\n\x08UserSpec\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9_][a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuota\"\xfb]\n\x0cUserSettings\x12\x36\n\x08readonly\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-2\x12-\n\tallow_ddl\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1d\x61llow_introspection_functions\x18` \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x0f\x63onnect_timeout\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12J\n\x1d\x63onnect_timeout_with_failover\x18\x61 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12<\n\x0freceive_timeout\x18( \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x39\n\x0csend_timeout\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12L\n\'timeout_before_checking_execution_speed\x18\x62 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\rinsert_quorum\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x15insert_quorum_timeout\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12:\n\x16insert_quorum_parallel\x18\x63 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x16insert_null_as_default\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dselect_sequential_consistency\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12V\n2deduplicate_blocks_in_dependent_materialized_views\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12O\n!replication_alter_partitions_sync\x18* \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-2\x12Z\n)max_replica_delay_for_distributed_queries\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12V\n2fallback_to_stale_replicas_for_distributed_queries\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x65\n\x18\x64istributed_product_mode\x18+ \x01(\x0e\x32\x43.yandex.cloud.mdb.clickhouse.v1.UserSettings.DistributedProductMode\x12L\n(distributed_aggregation_memory_efficient\x18H \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1c\x64istributed_ddl_task_timeout\x18I \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17skip_unavailable_shards\x18Q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13\x63ompile_expressions\x18. \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n\x1fmin_count_to_compile_expression\x18/ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12;\n\x0emax_block_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x1amin_insert_block_size_rows\x18\x30 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12I\n\x1bmin_insert_block_size_bytes\x18\x31 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x42\n\x15max_insert_block_size\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x1amin_bytes_to_use_direct_io\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x16use_uncompressed_cache\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n merge_tree_max_rows_to_use_cache\x18\x34 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12N\n!merge_tree_max_bytes_to_use_cache\x18\x35 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12T\n\'merge_tree_min_rows_for_concurrent_read\x18\x36 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12U\n(merge_tree_min_bytes_for_concurrent_read\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12G\n\"max_bytes_before_external_group_by\x18J \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_bytes_before_external_sort\x18K \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x41\n\x1cgroup_by_two_level_threshold\x18L \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n\"group_by_two_level_threshold_bytes\x18M \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x08priority\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x38\n\x0bmax_threads\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12>\n\x10max_memory_usage\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12G\n\x19max_memory_usage_for_user\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x15max_network_bandwidth\x18\x39 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_network_bandwidth_for_user\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x1fmax_partitions_per_insert_block\x18\x66 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x1fmax_concurrent_queries_for_user\x18g \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13\x66orce_index_by_date\x18; \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x66orce_primary_key\x18< \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x10max_rows_to_read\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_to_read\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12read_overflow_mode\x18\x0f \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_to_group_by\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12`\n\x16group_by_overflow_mode\x18\x11 \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.UserSettings.GroupByOverflowMode\x12>\n\x10max_rows_to_sort\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_to_sort\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12sort_overflow_mode\x18\x14 \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12=\n\x0fmax_result_rows\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_result_bytes\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12W\n\x14result_overflow_mode\x18\x17 \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_in_distinct\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_bytes_in_distinct\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Y\n\x16\x64istinct_overflow_mode\x18\x1a \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_to_transfer\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_bytes_to_transfer\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Y\n\x16transfer_overflow_mode\x18\x1d \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12@\n\x12max_execution_time\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12X\n\x15timeout_overflow_mode\x18\x1f \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12=\n\x0fmax_rows_in_set\x18W \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_bytes_in_set\x18X \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n\x11set_overflow_mode\x18Y \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12>\n\x10max_rows_in_join\x18Z \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_in_join\x18[ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12join_overflow_mode\x18\\ \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12R\n\x0ejoin_algorithm\x18h \x03(\x0e\x32:.yandex.cloud.mdb.clickhouse.v1.UserSettings.JoinAlgorithm\x12\x46\n\"any_join_distinct_right_table_keys\x18i \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x13max_columns_to_read\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_temporary_columns\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12M\n\x1fmax_temporary_non_const_columns\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12;\n\x0emax_query_size\x18# \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12:\n\rmax_ast_depth\x18$ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12=\n\x10max_ast_elements\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x46\n\x19max_expanded_ast_elements\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x41\n\x13min_execution_speed\x18T \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12G\n\x19min_execution_speed_bytes\x18U \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12o\n\x1d\x63ount_distinct_implementation\x18V \x01(\x0e\x32H.yandex.cloud.mdb.clickhouse.v1.UserSettings.CountDistinctImplementation\x12M\n)input_format_values_interpret_expressions\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n(input_format_defaults_for_omitted_fields\x18> \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12@\n\x1cinput_format_null_as_default\x18j \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x16\x64\x61te_time_input_format\x18k \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.UserSettings.DateTimeInputFormat\x12\x46\n\"input_format_with_names_use_header\x18l \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12p\n\'output_format_json_quote_64bit_integers\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValueR#outputFormatJsonQuote_64bitIntegers\x12\x46\n\"output_format_json_quote_denormals\x18@ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x62\n\x17\x64\x61te_time_output_format\x18m \x01(\x0e\x32\x41.yandex.cloud.mdb.clickhouse.v1.UserSettings.DateTimeOutputFormat\x12J\n&low_cardinality_allow_in_native_format\x18N \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n&allow_suspicious_low_cardinality_types\x18n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n)empty_result_for_aggregation_by_empty_set\x18O \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x17http_connection_timeout\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14http_receive_timeout\x18\x42 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11http_send_timeout\x18\x43 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17\x65nable_http_compression\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dsend_progress_in_http_headers\x18\x45 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x43\n\x1ehttp_headers_progress_interval\x18\x46 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x14\x61\x64\x64_http_cors_header\x18G \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12P\n,cancel_http_readonly_queries_on_client_close\x18o \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x16max_http_get_redirects\x18p \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1ejoined_subquery_requires_alias\x18] \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ejoin_use_nulls\x18^ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11transform_null_in\x18_ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\nquota_mode\x18P \x01(\x0e\x32\x36.yandex.cloud.mdb.clickhouse.v1.UserSettings.QuotaMode\x12\x32\n\x0e\x66latten_nested\x18q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rformat_regexp\x18r \x01(\t\x12j\n\x1b\x66ormat_regexp_escaping_rule\x18s \x01(\x0e\x32\x45.yandex.cloud.mdb.clickhouse.v1.UserSettings.FormatRegexpEscapingRule\x12@\n\x1c\x66ormat_regexp_skip_unmatched\x18t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61sync_insert\x18u \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x14\x61sync_insert_threads\x18v \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x15wait_for_async_insert\x18w \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1dwait_for_async_insert_timeout\x18x \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1a\x61sync_insert_max_data_size\x18y \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19\x61sync_insert_busy_timeout\x18z \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1a\x61sync_insert_stale_timeout\x18{ \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14memory_profiler_step\x18| \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12H\n\"memory_profiler_sample_probability\x18} \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12?\n\x11max_final_threads\x18~ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x1dinput_format_parallel_parsing\x18\x7f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x1finput_format_import_nested_json\x18\x80\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12m\n\x1clocal_filesystem_read_method\x18\x81\x01 \x01(\x0e\x32\x46.yandex.cloud.mdb.clickhouse.v1.UserSettings.LocalFilesystemReadMethod\x12\x42\n\x14max_read_buffer_size\x18\x82\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x19insert_keeper_max_retries\x18\x83\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12W\n(max_temporary_data_on_disk_size_for_user\x18\x84\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12X\n)max_temporary_data_on_disk_size_for_query\x18\x85\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x10max_parser_depth\x18\x86\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12o\n\x1dremote_filesystem_read_method\x18\x87\x01 \x01(\x0e\x32G.yandex.cloud.mdb.clickhouse.v1.UserSettings.RemoteFilesystemReadMethod\x12R\n#memory_overcommit_ratio_denominator\x18\x88\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12[\n,memory_overcommit_ratio_denominator_for_user\x18\x89\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\\\n-memory_usage_overcommit_max_wait_microseconds\x18\x8a\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12/\n\x07\x63ompile\x18, \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12=\n\x14min_count_to_compile\x18- \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\"_\n\x0cOverflowMode\x12\x1d\n\x19OVERFLOW_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13OVERFLOW_MODE_THROW\x10\x01\x12\x17\n\x13OVERFLOW_MODE_BREAK\x10\x02\"\xa1\x01\n\x13GroupByOverflowMode\x12&\n\"GROUP_BY_OVERFLOW_MODE_UNSPECIFIED\x10\x00\x12 \n\x1cGROUP_BY_OVERFLOW_MODE_THROW\x10\x01\x12 \n\x1cGROUP_BY_OVERFLOW_MODE_BREAK\x10\x02\x12\x1e\n\x1aGROUP_BY_OVERFLOW_MODE_ANY\x10\x03\"\xd2\x01\n\x16\x44istributedProductMode\x12(\n$DISTRIBUTED_PRODUCT_MODE_UNSPECIFIED\x10\x00\x12!\n\x1d\x44ISTRIBUTED_PRODUCT_MODE_DENY\x10\x01\x12\"\n\x1e\x44ISTRIBUTED_PRODUCT_MODE_LOCAL\x10\x02\x12#\n\x1f\x44ISTRIBUTED_PRODUCT_MODE_GLOBAL\x10\x03\x12\"\n\x1e\x44ISTRIBUTED_PRODUCT_MODE_ALLOW\x10\x04\"q\n\tQuotaMode\x12\x1a\n\x16QUOTA_MODE_UNSPECIFIED\x10\x00\x12\x16\n\x12QUOTA_MODE_DEFAULT\x10\x01\x12\x14\n\x10QUOTA_MODE_KEYED\x10\x02\x12\x1a\n\x16QUOTA_MODE_KEYED_BY_IP\x10\x03\"\xb6\x02\n\x1b\x43ountDistinctImplementation\x12-\n)COUNT_DISTINCT_IMPLEMENTATION_UNSPECIFIED\x10\x00\x12&\n\"COUNT_DISTINCT_IMPLEMENTATION_UNIQ\x10\x01\x12/\n+COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED\x10\x02\x12\x32\n.COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED_64\x10\x03\x12-\n)COUNT_DISTINCT_IMPLEMENTATION_UNIQ_HLL_12\x10\x04\x12,\n(COUNT_DISTINCT_IMPLEMENTATION_UNIQ_EXACT\x10\x05\"\x90\x02\n\rJoinAlgorithm\x12\x1e\n\x1aJOIN_ALGORITHM_UNSPECIFIED\x10\x00\x12\x17\n\x13JOIN_ALGORITHM_HASH\x10\x01\x12 \n\x1cJOIN_ALGORITHM_PARALLEL_HASH\x10\x02\x12 \n\x1cJOIN_ALGORITHM_PARTIAL_MERGE\x10\x03\x12\x19\n\x15JOIN_ALGORITHM_DIRECT\x10\x04\x12\x17\n\x13JOIN_ALGORITHM_AUTO\x10\x05\x12%\n!JOIN_ALGORITHM_FULL_SORTING_MERGE\x10\x06\x12\'\n#JOIN_ALGORITHM_PREFER_PARTIAL_MERGE\x10\x07\"\xad\x02\n\x18\x46ormatRegexpEscapingRule\x12+\n\'FORMAT_REGEXP_ESCAPING_RULE_UNSPECIFIED\x10\x00\x12\'\n#FORMAT_REGEXP_ESCAPING_RULE_ESCAPED\x10\x01\x12&\n\"FORMAT_REGEXP_ESCAPING_RULE_QUOTED\x10\x02\x12#\n\x1f\x46ORMAT_REGEXP_ESCAPING_RULE_CSV\x10\x03\x12$\n FORMAT_REGEXP_ESCAPING_RULE_JSON\x10\x04\x12#\n\x1f\x46ORMAT_REGEXP_ESCAPING_RULE_XML\x10\x05\x12#\n\x1f\x46ORMAT_REGEXP_ESCAPING_RULE_RAW\x10\x06\"\xb2\x01\n\x13\x44\x61teTimeInputFormat\x12&\n\"DATE_TIME_INPUT_FORMAT_UNSPECIFIED\x10\x00\x12&\n\"DATE_TIME_INPUT_FORMAT_BEST_EFFORT\x10\x01\x12 \n\x1c\x44\x41TE_TIME_INPUT_FORMAT_BASIC\x10\x02\x12)\n%DATE_TIME_INPUT_FORMAT_BEST_EFFORT_US\x10\x03\"\xb0\x01\n\x14\x44\x61teTimeOutputFormat\x12\'\n#DATE_TIME_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12\"\n\x1e\x44\x41TE_TIME_OUTPUT_FORMAT_SIMPLE\x10\x01\x12\x1f\n\x1b\x44\x41TE_TIME_OUTPUT_FORMAT_ISO\x10\x02\x12*\n&DATE_TIME_OUTPUT_FORMAT_UNIX_TIMESTAMP\x10\x03\"\xf2\x01\n\x19LocalFilesystemReadMethod\x12,\n(LOCAL_FILESYSTEM_READ_METHOD_UNSPECIFIED\x10\x00\x12%\n!LOCAL_FILESYSTEM_READ_METHOD_READ\x10\x01\x12\x31\n-LOCAL_FILESYSTEM_READ_METHOD_PREAD_THREADPOOL\x10\x02\x12&\n\"LOCAL_FILESYSTEM_READ_METHOD_PREAD\x10\x03\x12%\n!LOCAL_FILESYSTEM_READ_METHOD_NMAP\x10\x04\"\xa1\x01\n\x1aRemoteFilesystemReadMethod\x12-\n)REMOTE_FILESYSTEM_READ_METHOD_UNSPECIFIED\x10\x00\x12&\n\"REMOTE_FILESYSTEM_READ_METHOD_READ\x10\x01\x12,\n(REMOTE_FILESYSTEM_READ_METHOD_THREADPOOL\x10\x02J\x04\x08R\x10T\"\xee\x02\n\tUserQuota\x12\x42\n\x11interval_duration\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12\x35\n\x07queries\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x34\n\x06\x65rrors\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x0bresult_rows\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x37\n\tread_rows\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12<\n\x0e\x65xecution_time\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9_][a-zA-Z0-9_-]*\212\3101\004<=63'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _USERSETTINGS.fields_by_name['readonly']._options = None
  _USERSETTINGS.fields_by_name['readonly']._serialized_options = b'\372\3071\0030-2'
  _USERSETTINGS.fields_by_name['connect_timeout']._options = None
  _USERSETTINGS.fields_by_name['connect_timeout']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['connect_timeout_with_failover']._options = None
  _USERSETTINGS.fields_by_name['connect_timeout_with_failover']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['receive_timeout']._options = None
  _USERSETTINGS.fields_by_name['receive_timeout']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['send_timeout']._options = None
  _USERSETTINGS.fields_by_name['send_timeout']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['insert_quorum']._options = None
  _USERSETTINGS.fields_by_name['insert_quorum']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['insert_quorum_timeout']._options = None
  _USERSETTINGS.fields_by_name['insert_quorum_timeout']._serialized_options = b'\372\3071\006>=1000'
  _USERSETTINGS.fields_by_name['replication_alter_partitions_sync']._options = None
  _USERSETTINGS.fields_by_name['replication_alter_partitions_sync']._serialized_options = b'\372\3071\0030-2'
  _USERSETTINGS.fields_by_name['max_replica_delay_for_distributed_queries']._options = None
  _USERSETTINGS.fields_by_name['max_replica_delay_for_distributed_queries']._serialized_options = b'\372\3071\006>=1000'
  _USERSETTINGS.fields_by_name['min_count_to_compile_expression']._options = None
  _USERSETTINGS.fields_by_name['min_count_to_compile_expression']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_block_size']._options = None
  _USERSETTINGS.fields_by_name['max_block_size']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['min_insert_block_size_rows']._options = None
  _USERSETTINGS.fields_by_name['min_insert_block_size_rows']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['min_insert_block_size_bytes']._options = None
  _USERSETTINGS.fields_by_name['min_insert_block_size_bytes']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_insert_block_size']._options = None
  _USERSETTINGS.fields_by_name['max_insert_block_size']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['min_bytes_to_use_direct_io']._options = None
  _USERSETTINGS.fields_by_name['min_bytes_to_use_direct_io']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['merge_tree_max_rows_to_use_cache']._options = None
  _USERSETTINGS.fields_by_name['merge_tree_max_rows_to_use_cache']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['merge_tree_max_bytes_to_use_cache']._options = None
  _USERSETTINGS.fields_by_name['merge_tree_max_bytes_to_use_cache']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['merge_tree_min_rows_for_concurrent_read']._options = None
  _USERSETTINGS.fields_by_name['merge_tree_min_rows_for_concurrent_read']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['merge_tree_min_bytes_for_concurrent_read']._options = None
  _USERSETTINGS.fields_by_name['merge_tree_min_bytes_for_concurrent_read']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['priority']._options = None
  _USERSETTINGS.fields_by_name['priority']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_threads']._options = None
  _USERSETTINGS.fields_by_name['max_threads']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['max_memory_usage']._options = None
  _USERSETTINGS.fields_by_name['max_memory_usage']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_memory_usage_for_user']._options = None
  _USERSETTINGS.fields_by_name['max_memory_usage_for_user']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_to_read']._options = None
  _USERSETTINGS.fields_by_name['max_rows_to_read']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_bytes_to_read']._options = None
  _USERSETTINGS.fields_by_name['max_bytes_to_read']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_to_group_by']._options = None
  _USERSETTINGS.fields_by_name['max_rows_to_group_by']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_to_sort']._options = None
  _USERSETTINGS.fields_by_name['max_rows_to_sort']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_bytes_to_sort']._options = None
  _USERSETTINGS.fields_by_name['max_bytes_to_sort']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_result_rows']._options = None
  _USERSETTINGS.fields_by_name['max_result_rows']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_result_bytes']._options = None
  _USERSETTINGS.fields_by_name['max_result_bytes']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_in_distinct']._options = None
  _USERSETTINGS.fields_by_name['max_rows_in_distinct']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_bytes_in_distinct']._options = None
  _USERSETTINGS.fields_by_name['max_bytes_in_distinct']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_to_transfer']._options = None
  _USERSETTINGS.fields_by_name['max_rows_to_transfer']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_bytes_to_transfer']._options = None
  _USERSETTINGS.fields_by_name['max_bytes_to_transfer']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_execution_time']._options = None
  _USERSETTINGS.fields_by_name['max_execution_time']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_in_set']._options = None
  _USERSETTINGS.fields_by_name['max_rows_in_set']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_bytes_in_set']._options = None
  _USERSETTINGS.fields_by_name['max_bytes_in_set']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_rows_in_join']._options = None
  _USERSETTINGS.fields_by_name['max_rows_in_join']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_bytes_in_join']._options = None
  _USERSETTINGS.fields_by_name['max_bytes_in_join']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_columns_to_read']._options = None
  _USERSETTINGS.fields_by_name['max_columns_to_read']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_temporary_columns']._options = None
  _USERSETTINGS.fields_by_name['max_temporary_columns']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_temporary_non_const_columns']._options = None
  _USERSETTINGS.fields_by_name['max_temporary_non_const_columns']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_query_size']._options = None
  _USERSETTINGS.fields_by_name['max_query_size']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['max_ast_depth']._options = None
  _USERSETTINGS.fields_by_name['max_ast_depth']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['max_ast_elements']._options = None
  _USERSETTINGS.fields_by_name['max_ast_elements']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['max_expanded_ast_elements']._options = None
  _USERSETTINGS.fields_by_name['max_expanded_ast_elements']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['min_execution_speed']._options = None
  _USERSETTINGS.fields_by_name['min_execution_speed']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['min_execution_speed_bytes']._options = None
  _USERSETTINGS.fields_by_name['min_execution_speed_bytes']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_final_threads']._options = None
  _USERSETTINGS.fields_by_name['max_final_threads']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_read_buffer_size']._options = None
  _USERSETTINGS.fields_by_name['max_read_buffer_size']._serialized_options = b'\372\3071\002>0'
  _USERSETTINGS.fields_by_name['insert_keeper_max_retries']._options = None
  _USERSETTINGS.fields_by_name['insert_keeper_max_retries']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_temporary_data_on_disk_size_for_user']._options = None
  _USERSETTINGS.fields_by_name['max_temporary_data_on_disk_size_for_user']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_temporary_data_on_disk_size_for_query']._options = None
  _USERSETTINGS.fields_by_name['max_temporary_data_on_disk_size_for_query']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['max_parser_depth']._options = None
  _USERSETTINGS.fields_by_name['max_parser_depth']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['memory_overcommit_ratio_denominator']._options = None
  _USERSETTINGS.fields_by_name['memory_overcommit_ratio_denominator']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['memory_overcommit_ratio_denominator_for_user']._options = None
  _USERSETTINGS.fields_by_name['memory_overcommit_ratio_denominator_for_user']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['memory_usage_overcommit_max_wait_microseconds']._options = None
  _USERSETTINGS.fields_by_name['memory_usage_overcommit_max_wait_microseconds']._serialized_options = b'\372\3071\003>=0'
  _USERSETTINGS.fields_by_name['compile']._options = None
  _USERSETTINGS.fields_by_name['compile']._serialized_options = b'\030\001'
  _USERSETTINGS.fields_by_name['min_count_to_compile']._options = None
  _USERSETTINGS.fields_by_name['min_count_to_compile']._serialized_options = b'\030\001'
  _USERQUOTA.fields_by_name['interval_duration']._options = None
  _USERQUOTA.fields_by_name['interval_duration']._serialized_options = b'\372\3071\006>=1000'
  _USERQUOTA.fields_by_name['queries']._options = None
  _USERQUOTA.fields_by_name['queries']._serialized_options = b'\372\3071\003>=0'
  _USERQUOTA.fields_by_name['errors']._options = None
  _USERQUOTA.fields_by_name['errors']._serialized_options = b'\372\3071\003>=0'
  _USERQUOTA.fields_by_name['result_rows']._options = None
  _USERQUOTA.fields_by_name['result_rows']._serialized_options = b'\372\3071\003>=0'
  _USERQUOTA.fields_by_name['read_rows']._options = None
  _USERQUOTA.fields_by_name['read_rows']._serialized_options = b'\372\3071\003>=0'
  _USERQUOTA.fields_by_name['execution_time']._options = None
  _USERQUOTA.fields_by_name['execution_time']._serialized_options = b'\372\3071\003>=0'
  _globals['_USER']._serialized_start=141
  _globals['_USER']._serialized_end=369
  _globals['_PERMISSION']._serialized_start=371
  _globals['_PERMISSION']._serialized_end=412
  _globals['_USERSPEC']._serialized_start=415
  _globals['_USERSPEC']._serialized_end=704
  _globals['_USERSETTINGS']._serialized_start=707
  _globals['_USERSETTINGS']._serialized_end=12734
  _globals['_USERSETTINGS_OVERFLOWMODE']._serialized_start=10480
  _globals['_USERSETTINGS_OVERFLOWMODE']._serialized_end=10575
  _globals['_USERSETTINGS_GROUPBYOVERFLOWMODE']._serialized_start=10578
  _globals['_USERSETTINGS_GROUPBYOVERFLOWMODE']._serialized_end=10739
  _globals['_USERSETTINGS_DISTRIBUTEDPRODUCTMODE']._serialized_start=10742
  _globals['_USERSETTINGS_DISTRIBUTEDPRODUCTMODE']._serialized_end=10952
  _globals['_USERSETTINGS_QUOTAMODE']._serialized_start=10954
  _globals['_USERSETTINGS_QUOTAMODE']._serialized_end=11067
  _globals['_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION']._serialized_start=11070
  _globals['_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION']._serialized_end=11380
  _globals['_USERSETTINGS_JOINALGORITHM']._serialized_start=11383
  _globals['_USERSETTINGS_JOINALGORITHM']._serialized_end=11655
  _globals['_USERSETTINGS_FORMATREGEXPESCAPINGRULE']._serialized_start=11658
  _globals['_USERSETTINGS_FORMATREGEXPESCAPINGRULE']._serialized_end=11959
  _globals['_USERSETTINGS_DATETIMEINPUTFORMAT']._serialized_start=11962
  _globals['_USERSETTINGS_DATETIMEINPUTFORMAT']._serialized_end=12140
  _globals['_USERSETTINGS_DATETIMEOUTPUTFORMAT']._serialized_start=12143
  _globals['_USERSETTINGS_DATETIMEOUTPUTFORMAT']._serialized_end=12319
  _globals['_USERSETTINGS_LOCALFILESYSTEMREADMETHOD']._serialized_start=12322
  _globals['_USERSETTINGS_LOCALFILESYSTEMREADMETHOD']._serialized_end=12564
  _globals['_USERSETTINGS_REMOTEFILESYSTEMREADMETHOD']._serialized_start=12567
  _globals['_USERSETTINGS_REMOTEFILESYSTEMREADMETHOD']._serialized_end=12728
  _globals['_USERQUOTA']._serialized_start=12737
  _globals['_USERQUOTA']._serialized_end=13103
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Secret(google.protobuf.message.Message):
    """A secret that may contain several versions of the payload."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Secret._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Secret._Status.ValueType  # 0
        CREATING: Secret._Status.ValueType  # 1
        """The secret is being created."""
        ACTIVE: Secret._Status.ValueType  # 2
        """The secret is active and the secret payload can be accessed.

        Can be set to INACTIVE using the [SecretService.Deactivate] method.
        """
        INACTIVE: Secret._Status.ValueType  # 3
        """The secret is inactive and unusable.

        Can be set to ACTIVE using the [SecretService.Deactivate] method.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Secret.Status.ValueType  # 0
    CREATING: Secret.Status.ValueType  # 1
    """The secret is being created."""
    ACTIVE: Secret.Status.ValueType  # 2
    """The secret is active and the secret payload can be accessed.

    Can be set to INACTIVE using the [SecretService.Deactivate] method.
    """
    INACTIVE: Secret.Status.ValueType  # 3
    """The secret is inactive and unusable.

    Can be set to ACTIVE using the [SecretService.Deactivate] method.
    """

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CURRENT_VERSION_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the secret."""
    folder_id: builtins.str
    """ID of the folder that the secret belongs to."""
    name: builtins.str
    """Name of the secret."""
    description: builtins.str
    """Description of the secret."""
    kms_key_id: builtins.str
    """Optional ID of the KMS key will be used to encrypt and decrypt the secret."""
    status: global___Secret.Status.ValueType
    """Status of the secret."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the secret."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the secret as `key:value` pairs. Maximum 64 per key."""

    @property
    def current_version(self) -> global___Version:
        """Current (i.e. the `latest`) version of the secret."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        kms_key_id: builtins.str = ...,
        status: global___Secret.Status.ValueType = ...,
        current_version: global___Version | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "current_version", b"current_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "current_version", b"current_version", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "id", b"id", "kms_key_id", b"kms_key_id", "labels", b"labels", "name", b"name", "status", b"status"]) -> None: ...

global___Secret = Secret

@typing.final
class Version(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Version._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Version._Status.ValueType  # 0
        ACTIVE: Version._Status.ValueType  # 1
        """The version is active and the secret payload can be accessed."""
        SCHEDULED_FOR_DESTRUCTION: Version._Status.ValueType  # 2
        """The version is scheduled for destruction, the time when it will be destroyed
        is specified in the [Version.destroy_at] field.
        """
        DESTROYED: Version._Status.ValueType  # 3
        """The version is destroyed and cannot be recovered."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Version.Status.ValueType  # 0
    ACTIVE: Version.Status.ValueType  # 1
    """The version is active and the secret payload can be accessed."""
    SCHEDULED_FOR_DESTRUCTION: Version.Status.ValueType  # 2
    """The version is scheduled for destruction, the time when it will be destroyed
    is specified in the [Version.destroy_at] field.
    """
    DESTROYED: Version.Status.ValueType  # 3
    """The version is destroyed and cannot be recovered."""

    ID_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    DESTROY_AT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PAYLOAD_ENTRY_KEYS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the version."""
    secret_id: builtins.str
    """ID of the secret that the version belongs to."""
    description: builtins.str
    """Description of the version."""
    status: global___Version.Status.ValueType
    """Status of the secret."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the version was created."""

    @property
    def destroy_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the version is going to be destroyed. Empty unless the status
        is `SCHEDULED_FOR_DESTRUCTION`.
        """

    @property
    def payload_entry_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Keys of the entries contained in the version payload."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        secret_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        destroy_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        description: builtins.str = ...,
        status: global___Version.Status.ValueType = ...,
        payload_entry_keys: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "destroy_at", b"destroy_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "destroy_at", b"destroy_at", "id", b"id", "payload_entry_keys", b"payload_entry_keys", "secret_id", b"secret_id", "status", b"status"]) -> None: ...

global___Version = Version



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.apploadbalancer.v1.backend_group_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBackendGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to return.

    To get the backend group ID, make a [BackendGroupService.List] request.
    """
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id"]) -> None: ...

global___GetBackendGroupRequest = GetBackendGroupRequest

@typing.final
class ListBackendGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list backend groups in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListBackendGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListBackendGroupsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters backend groups listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [BackendGroup.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-backend-group`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBackendGroupsRequest = ListBackendGroupsRequest

@typing.final
class ListBackendGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListBackendGroupsRequest.page_size], use `next_page_token` as the value
    for the [ListBackendGroupsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def backend_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.backend_group_pb2.BackendGroup]:
        """List of backend groups in the specified folder."""

    def __init__(
        self,
        *,
        backend_groups: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.backend_group_pb2.BackendGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_groups", b"backend_groups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBackendGroupsResponse = ListBackendGroupsResponse

@typing.final
class DeleteBackendGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to delete.

    To get the backend group ID, make a [BackendGroupService.List] request.
    """
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id"]) -> None: ...

global___DeleteBackendGroupRequest = DeleteBackendGroupRequest

@typing.final
class DeleteBackendGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group that is being deleted."""
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id"]) -> None: ...

global___DeleteBackendGroupMetadata = DeleteBackendGroupMetadata

@typing.final
class UpdateBackendGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to update.

    To get the backend group ID, make a [BackendGroupService.List] request.
    """
    name: builtins.str
    """New name for the backend group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the backend group."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the backend group should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Backend group labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [BackendGroupService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def http(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackendGroup:
        """New list of HTTP backends that the backend group will consist of."""

    @property
    def grpc(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackendGroup:
        """New list of gRPC backends that the backend group will consist of."""

    @property
    def stream(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackendGroup:
        """New list of stream (TCP) backends that the backend group will consist of."""

    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        http: yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackendGroup | None = ...,
        grpc: yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackendGroup | None = ...,
        stream: yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackendGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend", b"backend", "grpc", b"grpc", "http", b"http", "stream", b"stream", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend", b"backend", "backend_group_id", b"backend_group_id", "description", b"description", "grpc", b"grpc", "http", b"http", "labels", b"labels", "name", b"name", "stream", b"stream", "update_mask", b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend", b"backend"]) -> typing.Literal["http", "grpc", "stream"] | None: ...

global___UpdateBackendGroupRequest = UpdateBackendGroupRequest

@typing.final
class UpdateBackendGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group that is being updated."""
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id"]) -> None: ...

global___UpdateBackendGroupMetadata = UpdateBackendGroupMetadata

@typing.final
class CreateBackendGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a backend group in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the backend group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the backend group."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Backend group labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    @property
    def http(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackendGroup:
        """List of HTTP backends that the backend group will consist of."""

    @property
    def grpc(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackendGroup:
        """List of gRPC backends that the backend group consists of."""

    @property
    def stream(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackendGroup:
        """List of stream (TCP) backends that the backend group consists of."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        http: yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackendGroup | None = ...,
        grpc: yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackendGroup | None = ...,
        stream: yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackendGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend", b"backend", "grpc", b"grpc", "http", b"http", "stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend", b"backend", "description", b"description", "folder_id", b"folder_id", "grpc", b"grpc", "http", b"http", "labels", b"labels", "name", b"name", "stream", b"stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend", b"backend"]) -> typing.Literal["http", "grpc", "stream"] | None: ...

global___CreateBackendGroupRequest = CreateBackendGroupRequest

@typing.final
class CreateBackendGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group that is being created."""
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id"]) -> None: ...

global___CreateBackendGroupMetadata = CreateBackendGroupMetadata

@typing.final
class AddBackendRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to add a backend to.

    To get the backend group ID, make a [BackendGroupService.List] request.
    """
    @property
    def http(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackend:
        """HTTP backend to add to the backend group."""

    @property
    def grpc(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackend:
        """gRPC backend to add to the backend group."""

    @property
    def stream(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackend:
        """New settings for the Stream backend."""

    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        http: yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackend | None = ...,
        grpc: yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackend | None = ...,
        stream: yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackend | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend", b"backend", "grpc", b"grpc", "http", b"http", "stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend", b"backend", "backend_group_id", b"backend_group_id", "grpc", b"grpc", "http", b"http", "stream", b"stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend", b"backend"]) -> typing.Literal["http", "grpc", "stream"] | None: ...

global___AddBackendRequest = AddBackendRequest

@typing.final
class AddBackendMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    BACKEND_NAME_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group that the backend is being added to."""
    backend_name: builtins.str
    """Name of the backend that is being added to the backend group."""
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        backend_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "backend_name", b"backend_name"]) -> None: ...

global___AddBackendMetadata = AddBackendMetadata

@typing.final
class UpdateBackendRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to update the backend in."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the backend should be updated."""

    @property
    def http(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackend:
        """New settings for the HTTP backend."""

    @property
    def grpc(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackend:
        """New settings for the gRPC backend."""

    @property
    def stream(self) -> yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackend:
        """New settings for the stream (TCP) backend."""

    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        http: yandex.cloud.apploadbalancer.v1.backend_group_pb2.HttpBackend | None = ...,
        grpc: yandex.cloud.apploadbalancer.v1.backend_group_pb2.GrpcBackend | None = ...,
        stream: yandex.cloud.apploadbalancer.v1.backend_group_pb2.StreamBackend | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backend", b"backend", "grpc", b"grpc", "http", b"http", "stream", b"stream", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend", b"backend", "backend_group_id", b"backend_group_id", "grpc", b"grpc", "http", b"http", "stream", b"stream", "update_mask", b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["backend", b"backend"]) -> typing.Literal["http", "grpc", "stream"] | None: ...

global___UpdateBackendRequest = UpdateBackendRequest

@typing.final
class UpdateBackendMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    BACKEND_NAME_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group that the backend is being updated it."""
    backend_name: builtins.str
    """Name of the backend that is being updated."""
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        backend_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "backend_name", b"backend_name"]) -> None: ...

global___UpdateBackendMetadata = UpdateBackendMetadata

@typing.final
class RemoveBackendRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    BACKEND_NAME_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to remove a backend from.

    To get the backend group ID, make a [BackendGroupService.List] request.
    """
    backend_name: builtins.str
    """Name of the backend to remove.

    To get the backend name, make a [BackendGroupService.Get] request.
    """
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        backend_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "backend_name", b"backend_name"]) -> None: ...

global___RemoveBackendRequest = RemoveBackendRequest

@typing.final
class RemoveBackendMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    BACKEND_NAME_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group that the backend is being removed from."""
    backend_name: builtins.str
    """Name of the backend that is being removed."""
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        backend_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "backend_name", b"backend_name"]) -> None: ...

global___RemoveBackendMetadata = RemoveBackendMetadata

@typing.final
class ListBackendGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group to get operations for.

    To get the backend group ID, use a [BackendGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListBackendGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListBackendGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBackendGroupOperationsRequest = ListBackendGroupOperationsRequest

@typing.final
class ListBackendGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListBackendGroupOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListBackendGroupOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified backend group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListBackendGroupOperationsResponse = ListBackendGroupOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogEntryResource(google.protobuf.message.Message):
    """Log entry resource specification.

    May be used either by services and by user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Resource type, i.e., `serverless.function`"""
    id: builtins.str
    """Resource ID, i.e., ID of the function producing logs."""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

global___LogEntryResource = LogEntryResource

@typing.final
class LogGroupResource(google.protobuf.message.Message):
    """Log group resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Resource type.

    Collected from log entries inside log group.
    """
    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of resource IDs with the same resource type."""

    def __init__(
        self,
        *,
        type: builtins.str = ...,
        ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ids", b"ids", "type", b"type"]) -> None: ...

global___LogGroupResource = LogGroupResource



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.smartwebsecurity.v1.security_profile_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSecurityProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """ID of the SecurityProfile resource to return."""
    def __init__(
        self,
        *,
        security_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_profile_id", b"security_profile_id"]) -> None: ...

global___GetSecurityProfileRequest = GetSecurityProfileRequest

@typing.final
class ListSecurityProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the security profile belongs to.
    Currently page_size, page_token, filter and order_by are not supported and List method will return all security profiles in the folder.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListSecurityProfilesRequest = ListSecurityProfilesRequest

@typing.final
class ListSecurityProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def security_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityProfile]:
        """List of SecurityProfile resources.
        Currently next_page_token is not supported and List method will return all security profiles in the folder.
        """

    def __init__(
        self,
        *,
        security_profiles: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_profiles", b"security_profiles"]) -> None: ...

global___ListSecurityProfilesResponse = ListSecurityProfilesResponse

@typing.final
class CreateSecurityProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a security profile in."""
    name: builtins.str
    """Name of the security profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the security profile."""
    default_action: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityProfile.DefaultAction.ValueType
    """Action to perform if none of rules matched."""
    captcha_id: builtins.str
    """Captcha ID to use with this security profile. Set empty to use default."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityRule]:
        """List of security rules."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        default_action: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityProfile.DefaultAction.ValueType = ...,
        security_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityRule] | None = ...,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id", "default_action", b"default_action", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "security_rules", b"security_rules"]) -> None: ...

global___CreateSecurityProfileRequest = CreateSecurityProfileRequest

@typing.final
class CreateSecurityProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """ID of the security profile that is being created."""
    def __init__(
        self,
        *,
        security_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_profile_id", b"security_profile_id"]) -> None: ...

global___CreateSecurityProfileMetadata = CreateSecurityProfileMetadata

@typing.final
class UpdateSecurityProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """ID of the security profile to update."""
    name: builtins.str
    """Name of the security profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the security profile."""
    default_action: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityProfile.DefaultAction.ValueType
    """Action to perform if none of rules matched."""
    captcha_id: builtins.str
    """Captcha ID to use with this security profile. Set empty to use default."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the SecurityProfile resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityRule]:
        """List of security rules."""

    def __init__(
        self,
        *,
        security_profile_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        default_action: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityProfile.DefaultAction.ValueType = ...,
        security_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.security_profile_pb2.SecurityRule] | None = ...,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id", "default_action", b"default_action", "description", b"description", "labels", b"labels", "name", b"name", "security_profile_id", b"security_profile_id", "security_rules", b"security_rules", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSecurityProfileRequest = UpdateSecurityProfileRequest

@typing.final
class UpdateSecurityProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """ID of the SecurityProfile resource that is being updated."""
    def __init__(
        self,
        *,
        security_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_profile_id", b"security_profile_id"]) -> None: ...

global___UpdateSecurityProfileMetadata = UpdateSecurityProfileMetadata

@typing.final
class DeleteSecurityProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """ID of the security profile to delete."""
    def __init__(
        self,
        *,
        security_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_profile_id", b"security_profile_id"]) -> None: ...

global___DeleteSecurityProfileRequest = DeleteSecurityProfileRequest

@typing.final
class DeleteSecurityProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """ID of the SecurityProfile resource that is being deleted."""
    def __init__(
        self,
        *,
        security_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_profile_id", b"security_profile_id"]) -> None: ...

global___DeleteSecurityProfileMetadata = DeleteSecurityProfileMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.subnet_pb2
import yandex.cloud.vpc.v1.subnet_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SubnetServiceStub:
    """A set of methods for managing Subnet resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.GetSubnetRequest,
        yandex.cloud.vpc.v1.subnet_pb2.Subnet,
    ]
    """Returns the specified Subnet resource.

    To get the list of available Subnet resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsRequest,
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsResponse,
    ]
    """Retrieves the list of Subnet resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.CreateSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a subnet in the specified folder and network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.UpdateSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    AddCidrBlocks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.AddSubnetCidrBlocksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds CIDR blocks to the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemoveCidrBlocks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.RemoveSubnetCidrBlocksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes CIDR blocks from the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.DeleteSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified subnet."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsRequest,
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsResponse,
    ]
    """List operations for the specified subnet."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.MoveSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move subnet to another folder."""

    Relocate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.RelocateSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    ListUsedAddresses: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesRequest,
        yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesResponse,
    ]
    """List used addresses in specified subnet."""

class SubnetServiceAsyncStub:
    """A set of methods for managing Subnet resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.GetSubnetRequest,
        yandex.cloud.vpc.v1.subnet_pb2.Subnet,
    ]
    """Returns the specified Subnet resource.

    To get the list of available Subnet resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsRequest,
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsResponse,
    ]
    """Retrieves the list of Subnet resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.CreateSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a subnet in the specified folder and network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.UpdateSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    AddCidrBlocks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.AddSubnetCidrBlocksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds CIDR blocks to the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemoveCidrBlocks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.RemoveSubnetCidrBlocksRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes CIDR blocks from the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.DeleteSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified subnet."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsRequest,
        yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsResponse,
    ]
    """List operations for the specified subnet."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.MoveSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move subnet to another folder."""

    Relocate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.RelocateSubnetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    ListUsedAddresses: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesRequest,
        yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesResponse,
    ]
    """List used addresses in specified subnet."""

class SubnetServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Subnet resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.GetSubnetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.subnet_pb2.Subnet, collections.abc.Awaitable[yandex.cloud.vpc.v1.subnet_pb2.Subnet]]:
        """Returns the specified Subnet resource.

        To get the list of available Subnet resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetsResponse]]:
        """Retrieves the list of Subnet resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.CreateSubnetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a subnet in the specified folder and network.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.UpdateSubnetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified subnet.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def AddCidrBlocks(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.AddSubnetCidrBlocksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds CIDR blocks to the specified subnet.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def RemoveCidrBlocks(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.RemoveSubnetCidrBlocksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes CIDR blocks from the specified subnet.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.DeleteSubnetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified subnet."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.subnet_service_pb2.ListSubnetOperationsResponse]]:
        """List operations for the specified subnet."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.MoveSubnetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Move subnet to another folder."""

    @abc.abstractmethod
    def Relocate(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.RelocateSubnetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def ListUsedAddresses(
        self,
        request: yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.subnet_service_pb2.ListUsedAddressesResponse]]:
        """List used addresses in specified subnet."""

def add_SubnetServiceServicer_to_server(servicer: SubnetServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
